<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.7.0
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

wc_print_notices();

do_action( 'woocommerce_before_cart' ); ?>
<div class="msg-cart">
	<p><?php echo esc_html__( 'Shipping & taxes calculated at checkout','modus' );?> <span><?php echo sprintf ( _n( '%d item', '%d items', WC()->cart->get_cart_contents_count(),'modus' ), WC()->cart->get_cart_contents_count() ); ?></span>
	</p>
</div>
<form action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">

	<?php do_action( 'woocommerce_before_cart_table' ); ?>

	<table class="shop_table shop_table_responsive cart modus-table-cart" cellspacing="0" border="1">
		<thead>
			<tr>
				<th class="col-md-1 col-xs-2 col-sm-2 product-thumbnail"><?php esc_html_e( 'Product', 'modus' ); ?></th>
				<th class="col-md-4 col-xs-4 col-sm-5 product-name"><?php esc_html_e( 'Title', 'modus' ); ?></th> 
				<th class="col-md-2 col-xs-1 col-sm-1 product-price"><?php esc_html_e( 'Price', 'modus' ); ?></th>
				<th class="col-md-2 col-xs-3 col-sm-2 product-quantity"><?php esc_html_e( 'Quantity', 'modus' ); ?></th>
				<th class="col-md-2 col-xs-1 col-sm-1 product-subtotal"><?php esc_html_e( 'Total', 'modus' ); ?></th>
				<th class="col-md-1 col-xs-1 col-sm-1 product-remove">x</th>
			</tr>
		</thead>
		<tbody>
			<?php do_action( 'woocommerce_before_cart_contents' ); ?>

			<?php
			foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
				$_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
				$product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

				if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
					$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
					?>
					<tr class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">
						<td class="product-thumbnail">
							<?php
								$thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image('shop_thumbnail'), $cart_item, $cart_item_key );
								if ( ! $product_permalink ) {
									echo wp_kses_post($thumbnail);
								} else {
									printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $thumbnail );
								}
							?>
						</td> 
						<td class="product-name" data-title="<?php esc_html_e( 'Product', 'modus' ); ?>">
							<?php
								if ( ! $product_permalink ) {
									echo apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key ) . '&nbsp;';
								} else {
									echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_title() ), $cart_item, $cart_item_key );
								} 
								// Meta data
								echo wc_get_formatted_cart_item_data( $cart_item ); 
								// Backorder notification
								if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
									echo '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'modus' ) . '</p>';
								}
							?>
						</td>
						 
						<td class="product-price" data-title="<?php esc_html_e( 'Price', 'modus' ); ?>">
							<?php
								echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
							?>
						</td>

						<td class="product-quantity" data-title="<?php esc_html_e( 'Quantity', 'modus' ); ?>">
							<?php
								if ( $_product->is_sold_individually() ) {
									$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
								} else {
									$product_quantity = woocommerce_quantity_input( array(
										'input_name'  => "cart[{$cart_item_key}][qty]",
										'input_value' => $cart_item['quantity'],
										'max_value'   => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
										'min_value'   => '0'
									), $_product, false );
								}

								echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item );
							?>
						</td>

						<td class="product-subtotal" data-title="<?php esc_html_e( 'Total', 'modus' ); ?>">
							<?php
								echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
							?>
						</td>
						<td class="product-remove">
							<?php
								echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
									'<a href="%s" class="remove" title="%s" data-product_id="%s" data-product_sku="%s"><i class="Pe-icon-7-stroke-trash"></i></a>',
									esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
									esc_html__( 'Remove this item', 'modus' ),
									esc_attr( $product_id ),
									esc_attr( $_product->get_sku() )
								), $cart_item_key );
							?>
						</td>

					</tr>
					<?php
				}
			}

			do_action( 'woocommerce_cart_contents' );
			?>
			<tr>
				<td colspan="8" class="actions">
					<div class="row">
						<div class="col-lg-6 col-md-6 col-sm-12 col-xs-12 btn-coup">
							<?php if ( wc_coupons_enabled() ) { ?>
								<div class="coupon">

									<label for="coupon_code"><?php esc_html_e( 'Coupon:', 'modus' ); ?></label> <input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Enter Coupon code', 'modus' ); ?>" /> <input type="submit" class="button" name="apply_coupon" value="<?php esc_attr_e( 'Apply Coupon', 'modus' ); ?>" />

									<?php do_action( 'woocommerce_cart_coupon' ); ?>
								</div>
							<?php } ?>
						</div>
						<div class="col-lg-6 col-md-6 col-sm-12 col-xs-12">
							<input type="submit" class="button update-disable display-inline" name="update_cart" value="<?php esc_attr_e( 'Update Cart', 'modus' ); ?>" />
							<div class="wc-proceed-to-checkout display-inline">
								<?php do_action( 'woocommerce_proceed_to_checkout' ); ?>
							</div>
						</div>
					</div>
					<?php do_action( 'woocommerce_cart_actions' ); ?>

					<?php wp_nonce_field( 'woocommerce-cart' ); ?>
				</td>
			</tr>

			<?php do_action( 'woocommerce_after_cart_contents' ); ?>
		</tbody>
	</table>

	<?php do_action( 'woocommerce_after_cart_table' ); ?>

</form>
<div class="cart-collaterals">
	<?php
		/**
		 * woocommerce_cart_collaterals hook.
		 *
		 * @hooked woocommerce_cross_sell_display
		 * @hooked woocommerce_cart_totals - 10
		 */
	 	//do_action( 'woocommerce_cart_collaterals' );
	?> 
	<div class="row">
		<?php 
			if ( 'yes' == get_option( 'woocommerce_enable_shipping_calc' )) :  
		?>
			<div class="col-md-6 col-sm-6 col-xs-12 shipping-total right">
				<div class="sidebar"><h2 class="widget-title"><?php esc_html_e('Calculate Shipping','modus')?></h2></div>
				<?php if ( WC()->cart->needs_shipping() && WC()->cart->show_shipping() ) : ?>

					<?php do_action( 'woocommerce_cart_totals_before_shipping' ); ?>

					<?php wc_cart_totals_shipping_html(); ?>

					<?php do_action( 'woocommerce_cart_totals_after_shipping' ); ?>

				<?php elseif ( WC()->cart->needs_shipping() && 'yes' === get_option( 'woocommerce_enable_shipping_calc' ) ) : ?>

					<tr class="shipping">
						<th><?php _e( 'Shipping', 'modus' ); ?></th>
						<td data-title="<?php esc_attr_e( 'Shipping', 'modus' ); ?>"><?php woocommerce_shipping_calculator(); ?></td>
					</tr>

				<?php endif; ?>
			</div>
		<?php
			endif;
		?>
		<div class="col-md-6 col-sm-6 col-xs-12 "> 
			<div class="sidebar"><h2 class="widget-title"><?php esc_html_e('Total','modus')?></span></div>
			<?php do_action( 'woocommerce_cart_collaterals' ); ?> 
		</div>

	</div> 
</div>

<?php do_action( 'woocommerce_after_cart' ); ?>
